@@ -1,6 +1,6 @@
 // vim: filetype=xs
 
-STRLEN CONCAT(estimate_, NAME)(SV * sv, int depth){
+STRLEN CONCAT(estimate_, NAME)(SV * sv){
     if( sv!=NULL ){
         if( SvROK(sv) && (!UNBLESSED || !sv_isobject(sv)) ){
             SV * rvs = SvRV(sv);
@@ -21,9 +21,7 @@ STRLEN CONCAT(estimate_, NAME)(SV * sv, int depth){
                     STRLEN len = 2 + n;
                     SV ** elems = AvARRAY(av);
                     for(int i=0; i<=n; ++i)
-                        len += CONCAT(estimate_, NAME)(elems[i], depth+1);
-                    if( PRETTY && n>0 )
-                        len += (n+1) * (depth*2+2);
+                        len += CONCAT(estimate_, NAME)(elems[i]);
                     --visited_p;
                     return len;
                 }
@@ -40,13 +38,10 @@ STRLEN CONCAT(estimate_, NAME)(SV * sv, int depth){
                         len += estimate_str((unsigned char*)key, (STRLEN) keylen);
 
                         SV * val = hv_iterval(hv, entry);
-                        len += CONCAT(estimate_, NAME)(val, depth+1);
-                        if( PRETTY )
-                            len += depth*2 + 3;
+                        len += CONCAT(estimate_, NAME)(val);
                     }
                     if( len==1 )
                         ++len;
-
                     --visited_p;
                     return len;
                 }
@@ -86,7 +81,7 @@ STRLEN CONCAT(estimate_, NAME)(SV * sv, int depth){
     return 4;
 }
 
-unsigned char * CONCAT(encode_, NAME)(unsigned char * buffer, SV * sv, int depth){
+unsigned char * CONCAT(encode_, NAME)(unsigned char * buffer, SV * sv){
     if( sv!=NULL ){
         if( SvROK(sv) && (!UNBLESSED || !sv_isobject(sv)) ){
             SV * rvs = SvRV(sv);
@@ -104,28 +99,10 @@ unsigned char * CONCAT(encode_, NAME)(unsigned char * buffer, SV * sv, int depth
                     if( n>=0 ){
                         SV ** elems = AvARRAY(av);
                         for(int i=0; i<n; ++i){
-                            if( PRETTY )
-                                *buffer++ = ' ';
-                            buffer = CONCAT(encode_, NAME)(buffer, elems[i], depth+1);
-                            if( PRETTY ){
-                                *buffer++ = '\n';
-                                for(int i=0; i<depth; ++i){
-                                    *buffer++ = ' ';
-                                    *buffer++ = ' ';
-                                }
-                            }
+                            buffer = CONCAT(encode_, NAME)(buffer, elems[i]);
                             *buffer++ = ',';
                         }
-                        if( PRETTY && n>0 )
-                            *buffer++ = ' ';
-                        buffer = CONCAT(encode_, NAME)(buffer, elems[n], depth+1);
-                        if( PRETTY && n>0 ){
-                            *buffer++ = '\n';
-                            for(int i=0; i<depth; ++i){
-                                *buffer++ = ' ';
-                                *buffer++ = ' ';
-                            }
-                        }
+                        buffer = CONCAT(encode_, NAME)(buffer, elems[n]);
                     }
 
                     *buffer++ = ']';
@@ -138,27 +115,16 @@ unsigned char * CONCAT(encode_, NAME)(unsigned char * buffer, SV * sv, int depth
 
                     hv_iterinit(hv);
                     for(HE * entry = hv_iternext(hv); entry; entry = hv_iternext(hv)){
-                        if( PRETTY )
-                            *buffer++ = ' ';
 
                         I32 keylen;
                         char * key = hv_iterkey(entry, &keylen);
                         buffer = encode_str(buffer, (unsigned char*)key, (STRLEN) keylen);
 
                         *buffer++ = ':';
-                        if( PRETTY )
-                            *buffer++ = ' ';
 
                         SV * val = hv_iterval(hv, entry);
-                        buffer = CONCAT(encode_, NAME)(buffer, val, depth+1);
+                        buffer = CONCAT(encode_, NAME)(buffer, val);
 
-                        if( PRETTY ){
-                            *buffer++ = '\n';
-                            for(int i=0; i<depth; ++i){
-                                *buffer++ = ' ';
-                                *buffer++ = ' ';
-                            }
-                        }
                         *buffer++ = ',';
                     }
 
